package io.renren.modules.admin.controller;

import java.util.Arrays;
import java.util.Collection;
import java.util.List;
import java.util.Map;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;

import org.apache.commons.lang.StringUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import io.renren.modules.admin.entity.AttendersEntity;
import io.renren.modules.admin.service.AttendersService;
import io.renren.common.utils.PageUtils;
import io.renren.common.utils.R;

/**
 * 
 *
 * @author chenshun
 * @email sunlightcs@gmail.com
 * @date 2020-02-21 15:10:27
 */
@RestController
@RequestMapping("admin/attenders")
public class AttendersController {
    @Autowired
    private AttendersService attendersService;

    /**
     * 列表
     */
    @RequestMapping("/list")
    @RequiresPermissions("admin:attenders:list")
    public R list(@RequestParam Map<String, Object> params) {
        PageUtils page = attendersService.queryPage(params);

        return R.ok().put("page", page);
    }

    /**
     * 信息
     */
    @RequestMapping("/info/{id}")
    @RequiresPermissions("admin:attenders:info")
    public R info(@PathVariable("id") Long id) {
        AttendersEntity attenders = attendersService.getById(id);

        return R.ok().put("attenders", attenders);
    }

    /**
     * 保存
     */
    @RequestMapping("/save")
    @RequiresPermissions("admin:attenders:save")
    public R save(@RequestBody AttendersEntity attenders) {
        attendersService.save(attenders);

        return R.ok();
    }

    /**
     * 修改
     */
    @RequestMapping("/update")
    @RequiresPermissions("admin:attenders:update")
    public R update(@RequestBody AttendersEntity attenders) {
        attendersService.updateById(attenders);

        return R.ok();
    }

    /**
     * 删除
     */
    @RequestMapping("/delete")
    @RequiresPermissions("admin:attenders:delete")
    public R delete(@RequestBody Long[] ids) {
        attendersService.removeByIds(Arrays.asList(ids));

        return R.ok();
    }

    /**
     * 根据name模糊查询
     */
    @GetMapping("/selectbyname")
    @RequiresPermissions("admin:attenders:info")
    public R getListByName(@RequestParam Map<String, Object> params) {
        if (!params.containsKey("name") || !params.containsKey("meetingId") ) {
            return R.error("姓名不能为空 or 会议id不为空");
        }
        String name = params.get("name").toString();
        Long meetingId = Long.valueOf(params.get("meetingId").toString());
        List<AttendersEntity> list = attendersService.list(
            new QueryWrapper<AttendersEntity>().eq("meeting_id", meetingId).like(StringUtils.isNotBlank(name) ,"name", name)
        );
        return R.ok().put("list", list);
    }
}
